@@ -8,7 +8,7 @@ from .parser import parse_results_from_file
 from .parser.results import _WPScanResults
 
 
-class WPScanOutParse:
+class WPScanOutParseCLI:
     def __init__(self):
         """Load all config values as object properties"""
 
@@ -81,7 +81,7 @@ class WPScanOutParse:
                 results["summary"] = None
 
             # Print infos if any
-            output = format_results(results, format=self.format)
+            output = format_results(results, format=self.format, nocolor=self.no_color)
             if output:
                 print(output)
         else:
@@ -151,6 +151,11 @@ It analyze vulnerabilities, miscellaneous alerts and warnings and other findings
             nargs="+",
             default=None,
         )
+        parser.add_argument(
+            "--no_color",
+            action="store_true",
+            help="do not colorize output. ",
+        )
         parser.add_argument(
             "--version",
             action="store_true",
@@ -163,7 +168,7 @@ It analyze vulnerabilities, miscellaneous alerts and warnings and other findings
 
 
 def main():
-    WPScanOutParse()
+    WPScanOutParseCLI()
 
 
 if __name__ == "__main__":
