@@ -1,8 +1,9 @@
 import json
 import re
+from string import Template
 
 
-def format_results(results, format):
+def format_results(results, format, warnings=True, infos=True, nocolor=False):
     """
     Format the results dict into a "html", "cli" or "json" string.
 
@@ -12,10 +13,16 @@ def format_results(results, format):
     if format == "json":
         return json.dumps(dict(results), indent=4)
     else:
-        return build_message(dict(results), format=format)
+        return build_message(
+            dict(results),
+            format=format,
+            warnings=warnings,
+            infos=infos,
+            nocolor=nocolor,
+        )
 
 
-def build_message(results, warnings=True, infos=True, format="cli"):
+def build_message(results, warnings=True, infos=True, format="cli", nocolor=False):
     """Build mail message text base on report and warnngs and info switch"""
     message = ""
     if results["error"]:
@@ -38,7 +45,9 @@ def build_message(results, warnings=True, infos=True, format="cli"):
             if results["summary"]["table"]:
                 summary.append(
                     format_summary_ascii_table(
-                        results["summary"]["table"], results["summary"]["line"]
+                        results["summary"]["table"],
+                        results["summary"]["line"],
+                        nocolor=nocolor,
                     )
                 )
             else:
@@ -47,7 +56,9 @@ def build_message(results, warnings=True, infos=True, format="cli"):
             if results["summary"]["table"]:
                 summary.append(
                     format_summary_html(
-                        results["summary"]["table"], results["summary"]["line"]
+                        results["summary"]["table"],
+                        results["summary"]["line"],
+                        nocolor=nocolor,
                     )
                 )
             else:
@@ -105,25 +116,102 @@ def format_issues(title, issues, format="cli", apply_br_tab_replace_on_issues=Tr
     return message
 
 
-def format_summary_ascii_table(table, line):
+def get_table_cell_color(col, val, ansi=False):
+    color = ""
+    if col == "Version State":
+        if ansi:
+            color = (
+                "yellow"
+                if "Outdated" in val
+                else "green"
+                if "Latest" in val
+                else "default"
+            )
+        else:
+            color = (
+                "#cccc00"
+                if "Outdated" in val
+                else "#228B22"
+                if "Latest" in val
+                else "#000000"
+            )
+    elif col == "Vulnerabilities":
+        if ansi:
+            color = "red" if val.isnumeric() and int(val) > 0 else "default"
+        else:
+            color = "#ba0000" if val.isnumeric() and int(val) > 0 else "#000000"
+    elif col == "Status":
+        if ansi:
+            color = (
+                "red"
+                if "Alert" in val
+                else "yellow"
+                if "Warning" in val
+                else "green"
+                if "Ok" in val
+                else "gray"
+                if "Unknown" in val
+                else "default"
+            )
+        else:
+            color = (
+                "#BA0000"
+                if "Alert" in val
+                else "#cccc00"
+                if "Warning" in val
+                else "#008000"
+                if "Ok" in val
+                else "#808080"
+                if "Unknown" in val
+                else "#000000"
+            )
+    return color
+
+
+def format_summary_ascii_table(table, line, nocolor=False):
     """Return a nice string table
     Author: Thierry Husson - Use it as you want but don't blame me.
     """
+    try:
+        from colors import color, ansilen
+    except ImportError:
+        nocolor = True
+
     myDict = table
     colList = ["Component", "Version", "Version State", "Vulnerabilities", "Status"]
     myList = [colList]  # 1st row = header
     for item in myDict:
         myList.append(
-            [str(item[col] if item[col] is not None else "") for col in colList]
+            [
+                str(
+                    item[col]
+                    if nocolor and item[col] is not None
+                    else color(
+                        str(item[col]),
+                        fg=get_table_cell_color(col, item[col], ansi=True),
+                    )
+                    if nocolor == False and item[col] is not None
+                    else ""
+                )
+                for col in colList
+            ]
         )
-    colSize = [max(map(len, col)) for col in zip(*myList)]
-    formatStr = " | ".join(["{{:<{}}}".format(i) for i in colSize])
+    colSize = [max(map(len if nocolor else ansilen, col)) for col in zip(*myList)]
+    formatStr = " | ".join(["{{:<{}s}}".format(i) for i in colSize])
     myList.insert(1, ["-" * i for i in colSize])  # Seperating line
-    string = "\n".join(formatStr.format(*item) for item in myList)
+    string = "\n".join(
+        formatStr.format(
+            *[
+                e.ljust(colSize[i] + (0 if nocolor else int(len(e) - ansilen(e))), " ")
+                for (i, e) in enumerate(item)
+            ]
+        )
+        for item in myList
+    )
     return string + "\n\n" + line
 
 
-def format_summary_html(table, line):
+def format_summary_html(table, line, nocolor):
     row_fmt = """      <tr>
         <td>{}</td>
         <td>{}</td>
@@ -137,20 +225,26 @@ def format_summary_html(table, line):
         table_rows += row_fmt.format(
             row["Component"],
             row["Version"],
-            row["Version State"],
-            row["Vulnerabilities"],
+            # Determine version state
+            '<span style="color:{color}">{vulns}</span>'.format(
+                vulns=row["Version State"],
+                color="#000000"
+                if nocolor
+                else get_table_cell_color("Version State", row["Version State"]),
+            ),
+            # Determine vulns color
+            '<span style="color:{color}">{vulns}</span>'.format(
+                vulns=row["Vulnerabilities"],
+                color="#000000"
+                if nocolor
+                else get_table_cell_color("Vulnerabilities", row["Vulnerabilities"]),
+            ),
             # Determine status color
             '<b style="color:{color}">{status}</b>'.format(
                 status=row["Status"],
-                color="#8B0000"
-                if row["Status"] == "Alert"
-                else "#FFD700"
-                if row["Status"] == "Warning"
-                else "#228B22"
-                if row["Status"] == "Ok"
-                else "#996633"
-                if row["Status"] == "Unknown"
-                else "#000000",
+                color="#000000"
+                if nocolor
+                else get_table_cell_color("Status", row["Status"]),
             ),
         )
 
