@@ -1,13 +1,12 @@
-from ..base import _Component
 from .finding import _CoreFindingNoVersion
 
 
-class NotFullyConfigured(_Component, _CoreFindingNoVersion):
+class NotFullyConfigured(_CoreFindingNoVersion):
     def __init__(self, data, *args, **kwargs):
         """From https://github.com/wpscanteam/wpscan/blob/master/app/views/json/core/not_fully_configured.erb"""
 
         super().__init__(data, *args, **kwargs)
-        self.not_fully_configured = data
+        self.not_fully_configured = self.data
 
     def get_alerts(self):
         """Return 1 alert"""
@@ -22,4 +21,4 @@ class NotFullyConfigured(_Component, _CoreFindingNoVersion):
         return []
 
     def get_name(self):
-        return "Noy fully configured"
+        return "Not fully configured"
